import logging
import os
from pypeepa.fileInteraction.createDirectory import createDirectory


def initLogging(app_name, level="INFO"):
    """
    Initialise Logging in your app
    @params: `app_name`:Name of your app\n\n
    @params: `level`:
        `DEBUG`: logging.DEBUG,\n
        `INFO`:(Default)logging.INFO,\n
        `WARNING`: logging.WARNING,\n
        `WARN`: logging.WARNING,\n
        `ERROR`: logging.ERROR,\n
        `CRITICAL`: logging.CRITICAL,\n
        `FATAL`: logging.CRITICAL,\n
    @return: Returns a logger object that you can use wherever you need to log.
    """

    level_mapping = {
        "DEBUG": logging.DEBUG,
        "INFO": logging.INFO,
        "WARNING": logging.WARNING,
        "WARN": logging.WARNING,
        "ERROR": logging.ERROR,
        "CRITICAL": logging.CRITICAL,
        "FATAL": logging.CRITICAL,
    }

    if level not in level_mapping:
        raise ValueError("Invalid log level specified")

    level_in_int = level_mapping[level]

    # Initialize logging
    log_directory = f"{os.path.expanduser('~')}/{app_name}_logs"
    createDirectory(log_directory)
    save_file_name: str = f"{log_directory}\ExceptionLogs-{app_name}.log"
    logging.basicConfig(
        filename=save_file_name,
        format="%(asctime)s %(message)s",
    )

    logger = logging.getLogger()
    logger.setLevel(level_in_int)
    logger.info(f"------------------{app_name} initialised!------------------")

    return logger



import re


def askYNQuestion(message):
    invalid_input = True
    return_val = False
    while invalid_input:
        user_input = input(f"{message} ")
        if bool(re.match(r"[YyNn]", user_input)):
            if bool(re.match(r"[Yy]", user_input)):
                return_val = True
                invalid_input = False
            elif bool(re.match(r"[Nn]", user_input)):
                return_val = False
                invalid_input = False
        else:
            print("\x1B[31mInvalid input! Please input either\x1B[37m y/n")
    return return_val



import os
from typing import List, Optional


def listDir(dir: str, get: Optional[str] = None) -> List[str]:
    content = []

    for content_path in os.listdir(dir):
        full_path = os.path.join(dir, content_path)

        if get is None:
            content.append(content_path)
        elif get == "files" and os.path.isfile(full_path):
            content.append(content_path)
        elif get == "folders" and os.path.isdir(full_path):
            content.append(content_path)

    return content
